# Spatial algebra  {#md_doc_a-features_a-spatial}

Spatial algebra is a mathematical notation commonly employed in rigid body
dynamics to represent and manipulate physical quantities such as velocities,
accelerations and forces. Pinocchio is based on this mathematical notation.
Dedicated classes are provided to represent coordinate transformations in the
3D Euclidean space (named SE3), spatial motion vectors (Motion), spatial force
vectors (Force), and spatial inertias (Inertia). Along with the available
methods, this endows Pinocchio with an efficient software library for spatial
algebra calculations.
